@@ -150,23 +150,25 @@ class FieldTreeNode(object):
         self.children = children or {}
 
 
-def make_field_tree(model, fields, exclude, force_recursion=False):
+def make_field_tree(model, fields, exclude, force_recursion=False, seen=None):
     no_explicit_fields = fields is None # assume we want all of them
     if no_explicit_fields:
         fields = model._meta.get_field_names()
     exclude = exclude or []
+    seen = seen or set()
 
     model_fields = []
     children = {}
 
     for field_obj in model._meta.get_fields():
-        if field_obj.name in exclude:
+        if field_obj.name in exclude or field_obj in seen:
             continue
 
         if field_obj.name in fields:
             model_fields.append(field_obj)
 
         if isinstance(field_obj, ForeignKeyField):
+            seen.add(field_obj)
             if no_explicit_fields:
                 rel_fields = None
             else:
@@ -181,7 +183,7 @@ def make_field_tree(model, fields, exclude, force_recursion=False):
                 rx.replace('%s__' % field_obj.name, '') \
                     for rx in exclude if rx.startswith('%s__' % field_obj.name)
             ]
-            children[field_obj.name] = make_field_tree(field_obj.rel_model, rel_fields, rel_exclude, force_recursion)
+            children[field_obj.name] = make_field_tree(field_obj.rel_model, rel_fields, rel_exclude, force_recursion, seen)
 
     return FieldTreeNode(model, model_fields, children)
 
@@ -323,7 +325,7 @@ class FilterForm(object):
                     idx = int(filter_idx)
                     cleaned.append((qf_s, idx, qf_v, filter_value))
                     query_filter = self._query_filters[field][idx]
-                    q_objects.append(query_filter.query(filter_value))
+                    q_objects.append(query_filter.query(field.db_value(filter_value)))
 
                 query = query.where(reduce(operator.or_, q_objects))
 
